@@ -1,4 +1,4 @@
-#-------------------------------------------------------------------------------
+#-------------------------------------------------------------------------
 #
 #  Copyright (c) 2009, Enthought, Inc.
 #  All rights reserved.
@@ -13,42 +13,40 @@
 #  Author: Evan Patterson
 #  Date:   06/22/2009
 #
-#-------------------------------------------------------------------------------
+#-------------------------------------------------------------------------
 
 """ A traits UI editor for editing tabular data (arrays, list of tuples, lists
     of objects, etc).
 """
 
-#-------------------------------------------------------------------------------
+#-------------------------------------------------------------------------
 #  Imports:
-#-------------------------------------------------------------------------------
+#-------------------------------------------------------------------------
+
+
 
 import os
 
 from pyface.qt import QtCore, QtGui
-
 from pyface.image_resource import ImageResource
+from pyface.ui_traits import Image
 
 from traits.api import (Any, Bool, Callable, Event, HasStrictTraits, Instance,
-    Int, List, NO_COMPARE, Property, TraitListEvent)
+                        Int, List, NO_COMPARE, Property, TraitListEvent)
 
 from traitsui.tabular_adapter import TabularAdapter
-from traitsui.ui_traits import Image
-
 from .editor import Editor
 from .tabular_model import TabularModel
 
 
-TRAITS_DEBUG = (os.getenv('TRAITS_DEBUG') is not None)
+class HeaderEventFilter(QtCore.QObject):
 
-
-class HeaderEventFilter(QtCore.QObject) :
-    def __init__(self, editor) :
+    def __init__(self, editor):
         super(HeaderEventFilter, self).__init__()
         self.editor = editor
 
-    def eventFilter(self, obj, event) :
-        if event.type() == QtCore.QEvent.ContextMenu :
+    def eventFilter(self, obj, event):
+        if event.type() == QtCore.QEvent.ContextMenu:
             self.editor._on_column_context_menu(event.pos())
             return True
         return False
@@ -59,7 +57,7 @@ class TabularEditor(Editor):
         lists of objects, etc).
     """
 
-    #-- Trait Definitions ------------------------------------------------------
+    #-- Trait Definitions ----------------------------------------------------
 
     # The event fired when a table update is needed:
     update = Event
@@ -69,16 +67,16 @@ class TabularEditor(Editor):
 
     # The current set of selected items (which one is used depends upon the
     # initial state of the editor factory 'multi_select' trait):
-    selected       = Any
+    selected = Any
     multi_selected = List
 
     # The current set of selected item indices (which one is used depends upon
     # the initial state of the editor factory 'multi_select' trait):
-    selected_row        = Int(-1)
+    selected_row = Int(-1)
     multi_selected_rows = List(Int)
 
     # The most recently actived item and its index:
-    activated     = Any(comparison_mode=NO_COMPARE)
+    activated = Any(comparison_mode=NO_COMPARE)
     activated_row = Int(comparison_mode=NO_COMPARE)
 
     # The most recent left click data:
@@ -130,11 +128,11 @@ class TabularEditor(Editor):
 
     widget_factory = Callable(lambda *args, **kwds: _TableView(*args, **kwds))
 
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
     #  Editor interface:
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
 
-    def init (self, parent):
+    def init(self, parent):
         """ Finishes initializing the editor by creating the underlying toolkit
             widget.
         """
@@ -149,8 +147,11 @@ class TabularEditor(Editor):
         if factory.multi_select:
             self.sync_value(factory.selected, 'multi_selected', 'both',
                             is_list=True)
-            self.sync_value(factory.selected_row, 'multi_selected_rows','both',
-                            is_list=True)
+            self.sync_value(
+                factory.selected_row,
+                'multi_selected_rows',
+                'both',
+                is_list=True)
         else:
             self.sync_value(factory.selected, 'selected', 'both')
             self.sync_value(factory.selected_row, 'selected_row', 'both')
@@ -160,38 +161,36 @@ class TabularEditor(Editor):
             slot = self._on_rows_selection
         else:
             slot = self._on_row_selection
-        signal = 'selectionChanged(QItemSelection,QItemSelection)'
-        QtCore.QObject.connect(self.control.selectionModel(),
-                               QtCore.SIGNAL(signal), slot)
+        selection_model = self.control.selectionModel()
+        selection_model.selectionChanged.connect(slot)
 
         # Synchronize other interesting traits as necessary:
-        self.sync_value(factory.update, 'update', 'from')
-        self.sync_value(factory.refresh, 'refresh', 'from')
-        self.sync_value(factory.activated,     'activated',     'to')
+        self.sync_value(factory.update, 'update', 'from', is_event=True)
+        self.sync_value(factory.refresh, 'refresh', 'from', is_event=True)
+        self.sync_value(factory.activated, 'activated', 'to')
         self.sync_value(factory.activated_row, 'activated_row', 'to')
-        self.sync_value(factory.clicked,  'clicked',  'to')
+        self.sync_value(factory.clicked, 'clicked', 'to')
         self.sync_value(factory.dclicked, 'dclicked', 'to')
-        self.sync_value(factory.right_clicked,  'right_clicked',  'to')
+        self.sync_value(factory.right_clicked, 'right_clicked', 'to')
         self.sync_value(factory.right_dclicked, 'right_dclicked', 'to')
         self.sync_value(factory.column_clicked, 'column_clicked', 'to')
-        self.sync_value(factory.column_right_clicked, 'column_right_clicked', 'to')
-        self.sync_value(factory.scroll_to_row, 'scroll_to_row', 'from')
+        self.sync_value(
+            factory.column_right_clicked,
+            'column_right_clicked',
+            'to')
+        self.sync_value(factory.scroll_to_row, 'scroll_to_row', 'from',
+                        is_event=True)
 
         # Connect other signals as necessary
-        signal = QtCore.SIGNAL('activated(QModelIndex)')
-        QtCore.QObject.connect(control, signal, self._on_activate)
-        signal = QtCore.SIGNAL('clicked(QModelIndex)')
-        QtCore.QObject.connect(control, signal, self._on_click)
-        signal = QtCore.SIGNAL('clicked(QModelIndex)')
-        QtCore.QObject.connect(control, signal, self._on_right_click)
-        signal = QtCore.SIGNAL('doubleClicked(QModelIndex)')
-        QtCore.QObject.connect(control, signal, self._on_dclick)
-        signal = QtCore.SIGNAL('sectionClicked(int)')
-        QtCore.QObject.connect(control.horizontalHeader(), signal, self._on_column_click)
+        control.activated.connect(self._on_activate)
+        control.clicked.connect(self._on_click)
+        control.clicked.connect(self._on_right_click)
+        control.doubleClicked.connect(self._on_dclick)
+        control.horizontalHeader().sectionClicked.connect(
+            self._on_column_click)
 
         control.setContextMenuPolicy(QtCore.Qt.CustomContextMenu)
-        signal = QtCore.SIGNAL('customContextMenuRequested(QPoint)')
-        QtCore.QObject.connect(control, signal, self._on_context_menu)
+        control.customContextMenuRequested.connect(self._on_context_menu)
 
         self.header_event_filter = HeaderEventFilter(self)
         control.horizontalHeader().installEventFilter(self.header_event_filter)
@@ -200,7 +199,7 @@ class TabularEditor(Editor):
         # replacements:
         try:
             self.context_object.on_trait_change(
-                self.update_editor, self.extended_name+'_items', dispatch='ui')
+                self.update_editor, self.extended_name + '_items', dispatch='ui')
         except:
             pass
 
@@ -223,7 +222,7 @@ class TabularEditor(Editor):
         self.on_trait_change(self.update_editor, 'adapter.columns',
                              dispatch='ui')
 
-    def dispose (self):
+    def dispose(self):
         """ Disposes of the contents of an editor.
         """
         self.context_object.on_trait_change(
@@ -247,15 +246,16 @@ class TabularEditor(Editor):
             editor.
         """
         if not self._no_update:
-            self.model.reset()
+            self.model.beginResetModel()
+            self.model.endResetModel()
             if self.factory.multi_select:
                 self._multi_selected_changed(self.multi_selected)
-            else :
+            else:
                 self._selected_changed(self.selected)
 
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
     #  TabularEditor interface:
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
 
     def refresh_editor(self):
         """ Requests the table view to redraw itself.
@@ -283,9 +283,9 @@ class TabularEditor(Editor):
         finally:
             self._no_notify = old
 
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
     #  UI preference save/restore interface:
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
 
     def restore_prefs(self, prefs):
         """ Restores any saved user preference information associated with the
@@ -300,13 +300,13 @@ class TabularEditor(Editor):
     def save_prefs(self):
         """ Returns any user preference information associated with the editor.
         """
-        widths = [ self.control.columnWidth(column)
-                   for column in range(len(self.adapter.columns)) ]
-        return { 'cached_widths': widths }
+        widths = [self.control.columnWidth(column)
+                  for column in range(len(self.adapter.columns))]
+        return {'cached_widths': widths}
 
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
     #  Private methods:
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
 
     def _add_image(self, image_resource):
         """ Adds a new image to the image map.
@@ -341,7 +341,7 @@ class TabularEditor(Editor):
                                    column=index.column())
         setattr(self, trait, event)
 
-    #-- Trait Event Handlers ---------------------------------------------------
+    #-- Trait Event Handlers -------------------------------------------------
 
     def _update_changed(self):
         self.update_editor()
@@ -351,14 +351,16 @@ class TabularEditor(Editor):
 
     def _selected_changed(self, new):
         if not self._no_update:
-            try:
-                selected_row = self.value.index(new)
-            except Exception as e:
-                if TRAITS_DEBUG:
-                    from traits.api import raise_to_debug
-                    raise_to_debug()
+            if new is None:
+                self._selected_row_changed(-1)
             else:
-                self._selected_row_changed(selected_row)
+                try:
+                    selected_row = self.value.index(new)
+                except Exception:
+                    from traitsui.api import raise_to_debug
+                    raise_to_debug()
+                else:
+                    self._selected_row_changed(selected_row)
 
     def _selected_row_changed(self, selected_row):
         if not self._no_update:
@@ -374,7 +376,7 @@ class TabularEditor(Editor):
         if not self._no_update:
             values = self.value
             try:
-                rows = [ values.index(i) for i in new]
+                rows = [values.index(i) for i in new]
             except:
                 pass
             else:
@@ -383,8 +385,8 @@ class TabularEditor(Editor):
     def _multi_selected_items_changed(self, event):
         values = self.value
         try:
-            added = [ values.index(item) for item in event.added ]
-            removed = [ values.index(item) for item in event.removed ]
+            added = [values.index(item) for item in event.added]
+            removed = [values.index(item) for item in event.removed]
         except:
             pass
         else:
@@ -396,11 +398,14 @@ class TabularEditor(Editor):
             smodel = self.control.selectionModel()
             selection = QtGui.QItemSelection()
             for row in selected_rows:
-                selection.select(self.model.index(row, 0), self.model.index(row, 0))
+                selection.select(
+                    self.model.index(
+                        row, 0), self.model.index(
+                        row, 0))
             smodel.clearSelection()
             smodel.select(selection,
-                QtGui.QItemSelectionModel.Select |
-                QtGui.QItemSelectionModel.Rows)
+                          QtGui.QItemSelectionModel.Select |
+                          QtGui.QItemSelectionModel.Rows)
 
     def _multi_selected_rows_items_changed(self, event):
         smodel = self.control.selectionModel()
@@ -414,19 +419,20 @@ class TabularEditor(Editor):
                           QtGui.QItemSelectionModel.Rows)
 
     scroll_to_row_hint_map = {
-        'center'  : QtGui.QTableView.PositionAtCenter,
-        'top'     : QtGui.QTableView.PositionAtTop,
-        'bottom'  : QtGui.QTableView.PositionAtBottom,
-        'visible' : QtGui.QTableView.EnsureVisible,
+        'center': QtGui.QTableView.PositionAtCenter,
+        'top': QtGui.QTableView.PositionAtTop,
+        'bottom': QtGui.QTableView.PositionAtBottom,
+        'visible': QtGui.QTableView.EnsureVisible,
     }
 
     def _scroll_to_row_changed(self, row):
         """ Scroll to the given row.
         """
-        scroll_hint = self.scroll_to_row_hint_map.get(self.factory.scroll_to_row_hint, self.control.PositionAtCenter)
+        scroll_hint = self.scroll_to_row_hint_map.get(
+            self.factory.scroll_to_row_hint, self.control.PositionAtCenter)
         self.control.scrollTo(self.model.index(row, 0), scroll_hint)
 
-    #-- Table Control Event Handlers -------------------------------------------
+    #-- Table Control Event Handlers -----------------------------------------
 
     def _on_activate(self, index):
         """ Handle a cell being activated.
@@ -490,32 +496,40 @@ class TabularEditor(Editor):
         finally:
             self._no_update = False
 
-    def _on_context_menu(self, pos) :
-        column, row = self.control.columnAt(pos.x()), self.control.rowAt(pos.y())
+    def _on_context_menu(self, pos):
+        column, row = self.control.columnAt(
+            pos.x()), self.control.rowAt(
+            pos.y())
         menu = self.adapter.get_menu(self.object, self.name, row, column)
-        if menu :
-            self._menu_context = {'selection' : self.object,
-                             'object':  self.object,
-                             'editor':  self,
-                             'column':  column,
-                             'row':     row,
-                             'item':    self.adapter.get_item(self.object, self.name, row),
-                             'info':    self.ui.info,
-                             'handler': self.ui.handler }
-            qmenu = menu.create_menu( self.control, self )
+        if menu:
+            self._menu_context = {
+                'selection': self.object,
+                'object': self.object,
+                'editor': self,
+                'column': column,
+                'row': row,
+                'item': self.adapter.get_item(
+                    self.object,
+                    self.name,
+                    row),
+                'info': self.ui.info,
+                'handler': self.ui.handler}
+            qmenu = menu.create_menu(self.control, self)
             qmenu.exec_(self.control.mapToGlobal(pos))
             self._menu_context = None
 
-    def _on_column_context_menu(self, pos) :
+    def _on_column_context_menu(self, pos):
         column = self.control.columnAt(pos.x())
         menu = self.adapter.get_column_menu(self.object, self.name, -1, column)
-        if menu :
-            self._menu_context = {'selection' : self.object, 'object':  self.object,
-                             'editor':  self,
-                             'column':  column,
-                             'info':    self.ui.info,
-                             'handler': self.ui.handler }
-            qmenu = menu.create_menu( self.control, self )
+        if menu:
+            self._menu_context = {
+                'selection': self.object,
+                'object': self.object,
+                'editor': self,
+                'column': column,
+                'info': self.ui.info,
+                'handler': self.ui.handler}
+            qmenu = menu.create_menu(self.control, self)
             qmenu.exec_(self.control.mapToGlobal(pos))
             self._menu_context = None
         else:
@@ -523,9 +537,9 @@ class TabularEditor(Editor):
             self._on_column_right_click(column)
 
 
-#-------------------------------------------------------------------------------
+#-------------------------------------------------------------------------
 #  'TabularEditorEvent' class:
-#-------------------------------------------------------------------------------
+#-------------------------------------------------------------------------
 
 class TabularEditorEvent(HasStrictTraits):
 
@@ -538,20 +552,21 @@ class TabularEditorEvent(HasStrictTraits):
     # The row item:
     item = Property
 
-    #-- Private Traits ---------------------------------------------------------
+    #-- Private Traits -------------------------------------------------------
 
     # The editor the event is associated with:
     editor = Instance(TabularEditor)
 
-    #-- Property Implementations -----------------------------------------------
+    #-- Property Implementations ---------------------------------------------
 
     def _get_item(self):
         editor = self.editor
         return editor.adapter.get_item(editor.object, editor.name, self.row)
 
-#-------------------------------------------------------------------------------
+#-------------------------------------------------------------------------
 #  Qt widgets that have been configured to behave as expected by Traits UI:
-#-------------------------------------------------------------------------------
+#-------------------------------------------------------------------------
+
 
 class _ItemDelegate(QtGui.QStyledItemDelegate):
     """ A QStyledItemDelegate which draws its owns gridlines so that we can
@@ -579,12 +594,15 @@ class _ItemDelegate(QtGui.QStyledItemDelegate):
         painter.setPen(option.palette.color(QtGui.QPalette.Dark))
 
         if self._horizontal_lines:
-            painter.drawLine(option.rect.bottomLeft(),option.rect.bottomRight())
+            painter.drawLine(
+                option.rect.bottomLeft(),
+                option.rect.bottomRight())
         if self._vertical_lines:
             painter.drawLine(option.rect.topRight(), option.rect.bottomRight())
 
         painter.restore()
 
+
 class _TableView(QtGui.QTableView):
     """ A QTableView configured to behave as expected by TraitsUI.
     """
@@ -617,7 +635,9 @@ class _TableView(QtGui.QTableView):
             size = vheader.minimumSectionSize()
             font = editor.adapter.get_font(editor.object, editor.name, 0)
             if font is not None:
-                size = max(size, QtGui.QFontMetrics(QtGui.QFont(font)).height())
+                size = max(
+                    size, QtGui.QFontMetrics(
+                        QtGui.QFont(font)).height())
             vheader.setDefaultSectionSize(size)
 
         # Configure the column headings.
@@ -658,7 +678,7 @@ class _TableView(QtGui.QTableView):
         # most platforms, which is why we do this here.
         if (event.key() in (QtCore.Qt.Key_Enter, QtCore.Qt.Key_Return) and
             self.state() != QtGui.QAbstractItemView.EditingState and
-            factory.editable and 'edit' in factory.operations):
+                factory.editable and 'edit' in factory.operations):
             if factory.multi_select:
                 rows = editor.multi_selected_rows
                 row = rows[0] if len(rows) == 1 else -1
@@ -718,7 +738,7 @@ class _TableView(QtGui.QTableView):
 
         parent = self.parent()
         if (not self._initial_size and parent and
-            (self.isVisible() or isinstance(parent, QtGui.QMainWindow))):
+                (self.isVisible() or isinstance(parent, QtGui.QMainWindow))):
             self._initial_size = True
             self.resizeColumnsToContents()
 
@@ -754,7 +774,8 @@ class _TableView(QtGui.QTableView):
         # Assign sizes for columns with absolute size requests
         percent_vals, percent_cols = [], []
         for column in range(len(editor.adapter.columns)):
-            width = editor.adapter.get_width(editor.object, editor.name, column)
+            width = editor.adapter.get_width(
+                editor.object, editor.name, column)
             if width > 1:
                 available_space -= width
                 hheader.resizeSection(column, width)
