@@ -18,137 +18,141 @@
 """ Trait definition for a wxPython-based font.
 """
 
-#-------------------------------------------------------------------------------
+#-------------------------------------------------------------------------
 #  Imports:
-#-------------------------------------------------------------------------------
+#-------------------------------------------------------------------------
 
 import wx
 
 from traits.api \
     import Trait, TraitHandler, TraitError
 
-#-------------------------------------------------------------------------------
+#-------------------------------------------------------------------------
 #  Convert a string into a valid 'wxFont' object (if possible):
-#-------------------------------------------------------------------------------
+#-------------------------------------------------------------------------
 
 # Mapping of strings to valid wxFont families
 font_families = {
-    'default':    wx.DEFAULT,
-    'decorative': wx.DECORATIVE,
-    'roman':      wx.ROMAN,
-    'script':     wx.SCRIPT,
-    'swiss':      wx.SWISS,
-    'modern':     wx.MODERN
+    'default': wx.FONTFAMILY_DEFAULT,
+    'decorative': wx.FONTFAMILY_DECORATIVE,
+    'roman': wx.FONTFAMILY_ROMAN,
+    'script': wx.FONTFAMILY_SCRIPT,
+    'swiss': wx.FONTFAMILY_SWISS,
+    'modern': wx.FONTFAMILY_MODERN
 }
 
 # Mapping of strings to wxFont styles
 font_styles = {
-    'slant':  wx.SLANT,
-    'italic': wx.ITALIC
+    'slant': wx.FONTSTYLE_SLANT,
+    'italic': wx.FONTSTYLE_ITALIC
 }
 
 # Mapping of strings wxFont weights
 font_weights = {
-    'light': wx.LIGHT,
-    'bold':  wx.BOLD
+    'light': wx.FONTWEIGHT_LIGHT,
+    'bold': wx.FONTWEIGHT_BOLD
 }
 
 # Strings to ignore in text representations of fonts
-font_noise = [ 'pt', 'point', 'family' ]
+font_noise = ['pt', 'point', 'family']
 
-#-------------------------------------------------------------------------------
+#-------------------------------------------------------------------------
 #  Converts a wx.Font into a string description of itself:
-#-------------------------------------------------------------------------------
+#-------------------------------------------------------------------------
 
-def font_to_str ( font ):
+
+def font_to_str(font):
     """ Converts a wx.Font into a string description of itself.
     """
-    weight = { wx.LIGHT:  ' Light',
-               wx.BOLD:   ' Bold'   }.get( font.GetWeight(), '' )
-    style  = { wx.SLANT:  ' Slant',
-               wx.ITALIC: ' Italic' }.get( font.GetStyle(), '' )
+    weight = {wx.FONTWEIGHT_LIGHT: ' Light',
+              wx.FONTWEIGHT_BOLD: ' Bold'}.get(font.GetWeight(), '')
+    style = {wx.FONTSTYLE_SLANT: ' Slant',
+             wx.FONTSTYLE_ITALIC: ' Italic'}.get(font.GetStyle(), '')
     underline = ''
     if font.GetUnderlined():
         underline = ' underline'
     return '%s point %s%s%s%s' % (
-           font.GetPointSize(), font.GetFaceName(), style, weight, underline )
+           font.GetPointSize(), font.GetFaceName(), style, weight, underline)
 
-#-------------------------------------------------------------------------------
+#-------------------------------------------------------------------------
 #  Create a TraitFont object from a string description:
-#-------------------------------------------------------------------------------
+#-------------------------------------------------------------------------
 
-def create_traitsfont ( value ):
+
+def create_traitsfont(value):
     """ Create a TraitFont object from a string description.
     """
-    if isinstance( value, wx.Font ):
-        value = font_to_str( value )
+    if isinstance(value, wx.Font):
+        value = font_to_str(value)
 
     point_size = None
-    family     = wx.DEFAULT
-    style      = wx.NORMAL
-    weight     = wx.NORMAL
-    underline  = 0
-    facename   = []
+    family = wx.FONTFAMILY_DEFAULT
+    style = wx.FONTSTYLE_NORMAL
+    weight = wx.FONTWEIGHT_NORMAL
+    underline = 0
+    facename = []
     for word in value.split():
         lword = word.lower()
         if lword in font_families:
-            family = font_families[ lword ]
+            family = font_families[lword]
         elif lword in font_styles:
-            style = font_styles[ lword ]
+            style = font_styles[lword]
         elif lword in font_weights:
-            weight = font_weights[ lword ]
+            weight = font_weights[lword]
         elif lword == 'underline':
             underline = 1
         elif lword not in font_noise:
             if point_size is None:
                 try:
-                    point_size = int( lword )
+                    point_size = int(lword)
                     continue
                 except:
                     pass
-            facename.append( word )
-    return TraitsFont( point_size or 10, family, style, weight, underline,
-                    ' '.join( facename ) )
+            facename.append(word)
+    return TraitsFont(point_size or 10, family, style, weight, underline,
+                      ' '.join(facename))
 
-#-------------------------------------------------------------------------------
+#-------------------------------------------------------------------------
 #  'TraitsFont' class:
-#-------------------------------------------------------------------------------
+#-------------------------------------------------------------------------
 
-class TraitsFont ( wx.Font ):
+
+class TraitsFont(wx.Font):
     """ A Traits-specific wx.Font.
     """
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
     #  Returns the pickleable form of a TraitsFont object:
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
 
-    def __reduce_ex__ ( self, protocol ):
+    def __reduce_ex__(self, protocol):
         """ Returns the pickleable form of a TraitsFont object.
         """
-        return ( create_traitsfont, ( font_to_str( self ), ) )
+        return (create_traitsfont, (font_to_str(self), ))
 
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
     #  Returns a printable form of the font:
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
 
-    def __str__ ( self ):
+    def __str__(self):
         """ Returns a printable form of the font.
         """
-        return font_to_str( self )
+        return font_to_str(self)
 
-#-------------------------------------------------------------------------------
+#-------------------------------------------------------------------------
 #  'TraitWXFont' class'
-#-------------------------------------------------------------------------------
+#-------------------------------------------------------------------------
 
-class TraitWXFont ( TraitHandler ):
+
+class TraitWXFont(TraitHandler):
     """ Ensures that values assigned to a trait attribute are valid font
     descriptor strings; the value actually assigned is the corresponding
     TraitsFont.
     """
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
     #  Validates that the value is a valid font:
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
 
-    def validate ( self, object, name, value ):
+    def validate(self, object, name, value):
         """ Validates that the value is a valid font descriptor string. If so,
         it returns the corresponding TraitsFont; otherwise, it raises a
         TraitError.
@@ -157,20 +161,20 @@ class TraitWXFont ( TraitHandler ):
             return None
 
         try:
-            return create_traitsfont( value )
+            return create_traitsfont(value)
         except:
             pass
 
         raise TraitError(object, name, 'a font descriptor string',
                          repr(value))
 
-    def info ( self ):
-        return ( "a string describing a font (e.g. '12 pt bold italic "
-                 "swiss family Arial' or 'default 12')" )
+    def info(self):
+        return ("a string describing a font (e.g. '12 pt bold italic "
+                "swiss family Arial' or 'default 12')")
 
-#-------------------------------------------------------------------------------
+#-------------------------------------------------------------------------
 #  Define a wxPython specific font trait:
-#-------------------------------------------------------------------------------
+#-------------------------------------------------------------------------
 
 ### Note: Declare the editor to be a function which returns the FontEditor
 # class from traits ui to avoid circular import issues. For backwards
@@ -178,9 +182,15 @@ class TraitWXFont ( TraitHandler ):
 # project declares 'from api import *' in its __init__.py. The 'api' in turn
 # can contain classes that have a Font trait which lead to this file getting
 # imported. This leads to a circular import when declaring a Font trait.
+
+
 def get_font_editor(*args, **traits):
     from .font_editor import ToolkitEditorFactory
     return ToolkitEditorFactory(*args, **traits)
 
-fh     = TraitWXFont()
-WxFont = Trait( wx.SystemSettings_GetFont( wx.SYS_DEFAULT_GUI_FONT ), fh, editor = get_font_editor )
+fh = TraitWXFont()
+WxFont = Trait(
+    wx.SystemSettings.GetFont(
+        wx.SYS_DEFAULT_GUI_FONT),
+    fh,
+    editor=get_font_editor)
